import { 
  			select, 
        csv, 
        scaleLinear, 
        max, 
        scaleBand, 
        axisLeft,
  			axisBottom
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

//returns a promise once the data is loaded 
//parses csv into an array of objects
//one object for each row
//need to check data type of each attribute
//i.e. population value is imported as a string

const render = data => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = {top: 20, right: 40, bottom: 20, left: 100};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  
  //domain = data space
  //range = screen space
  //linear scales good for quantitative data
  //linear scale == linear stretch
  
  const xScale = scaleLinear()
  
  	//max function (d3) accepts 2 arguments
  	//first is the data, second is a column
  
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth]);
  
  
  
  //band scale for ordinal data
  
  const yScale = scaleBand()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.1);
  
  
  const g = svg.append('g').attr('transform', `translate(${margin.left},${margin.top})`);
  
	//invoke yAxis and pass in new group element
  //call a function and pass in a selection
  //short hand is .call
  g.append('g').call(axisLeft(yScale));
  g.append('g').call(axisBottom(xScale))
  	.attr('transform', `translate(0,${innerHeight})`);
  
  g.selectAll('rect').data(data)
  	.enter().append('rect')
  		.attr('y', d => yScale(yValue(d)))
  		.attr('width', d => xScale(xValue(d)))
  		//bandwidth is the computed height of a single bar
  		.attr('height', yScale.bandwidth());
  
  
};

csv('data.csv').then(data => {
  //d represents one row from the original table
  
  data.forEach(d => {
    
    //convert strings to floats
    //values are in thousands 
    //multiple to get actual values
    
    d.population = +d.population * 1000;
  });
  render(data)
});

